@@ -1,12 +1,12 @@
 #' Classify the distribution of a model-family using machine learning
 #'
-#' Choosing the right distributional family for regression models is essential
-#' to get more accurate estimates and standard errors. This function may help to
-#' Machine learning model trained to classify distributions
-#'
-#' Mean accuracy and Kappa of 0.86 and 0.85, repsectively.
-#'
-"classify_distribution"
+#' @name classify_distribution
+#' @docType data
+#' @keywords data
+#' @details
+#' The trained model to classify distributions, which is used by the
+#' `check_distribution()` function.
+NULL
 
 
 #' Classify the distribution of a model-family using machine learning
@@ -82,7 +82,7 @@ check_distribution.default <- function(model) {
 
 
   # Extract features
-  x <- datawizard::data_to_numeric(insight::get_response(model, verbose = FALSE), dummy_factors = FALSE, preserve_levels = TRUE)
+  x <- datawizard::to_numeric(insight::get_response(model, verbose = FALSE), dummy_factors = FALSE, preserve_levels = TRUE)
   dat <- .extract_features(x)
 
   dist_response <- as.data.frame(t(stats::predict(classify_distribution, dat, type = "prob")))
