@@ -180,18 +180,18 @@ compare_performance <- function(..., metrics = "all", rank = FALSE, estimator =
 
   # for REML fits, warn user
   if (isTRUE(verbose) &&
-      # only warn for REML fit
-      identical(estimator, "REML") &&
-      # only for IC comparison
-      any(grepl("(AIC|BIC)", names(dfs))) &&
-      # only when mixed models are involved, others probably don't have problems with REML fit
-      any(sapply(objects, insight::is_mixed_model)) &&
-      # only if not all models have same fixed effects (else, REML is ok)
-      !isTRUE(attributes(objects)$same_fixef)) {
-      warning(insight::format_message(
-        "Information criteria (like AIC) are based on REML fits (i.e. `estimator=\"REML\"`).",
-        "Please note that information criteria are probably not directly comparable and that it is not recommended comparing models with different fixed effects in such cases."
-      ), call. = FALSE)
+    # only warn for REML fit
+    identical(estimator, "REML") &&
+    # only for IC comparison
+    any(grepl("(AIC|BIC)", names(dfs))) &&
+    # only when mixed models are involved, others probably don't have problems with REML fit
+    any(sapply(objects, insight::is_mixed_model)) &&
+    # only if not all models have same fixed effects (else, REML is ok)
+    !isTRUE(attributes(objects)$same_fixef)) {
+    warning(insight::format_message(
+      "Information criteria (like AIC) are based on REML fits (i.e. `estimator=\"REML\"`).",
+      "Please note that information criteria are probably not directly comparable and that it is not recommended comparing models with different fixed effects in such cases."
+    ), call. = FALSE)
   }
 
   # dfs[order(sapply(object_names, as.character), dfs$Model), ]
@@ -204,7 +204,8 @@ compare_performance <- function(..., metrics = "all", rank = FALSE, estimator =
 # methods ----------------------------
 
 #' @export
-print.compare_performance <- function(x, digits = 3, ...) {
+print.compare_performance <- function(x, digits = 3, layout = "horizontal", ...) {
+  layout <- match.arg(layout, choices = c("horizontal", "vertical"))
   table_caption <- c("# Comparison of Model Performance Indices", "blue")
   formatted_table <- format(x = x, digits = digits, format = "text", ...)
 
@@ -214,6 +215,13 @@ print.compare_performance <- function(x, digits = 3, ...) {
     footer <- NULL
   }
 
+  # switch to vertical layout
+  if (layout == "vertical") {
+    formatted_table <- datawizard::rownames_as_column(as.data.frame(t(formatted_table)), "Metric")
+    formatted_table <- datawizard::row_to_colnames(formatted_table)
+    colnames(formatted_table)[1] <- "Metric"
+  }
+
   cat(insight::export_table(x = formatted_table, digits = digits, format = "text", caption = table_caption, footer = footer, ...))
   invisible(x)
 }
@@ -298,6 +306,9 @@ plot.compare_performance <- function(x, ...) {
 
 
 .normalize_vector <- function(x) {
+  if (all(is.na(x)) || all(is.infinite(x))) {
+    return(x)
+  }
   as.vector((x - min(x, na.rm = TRUE)) / diff(range(x, na.rm = TRUE), na.rm = TRUE))
 }
 
