@@ -23,8 +23,10 @@ if (.runThisTest && !osx) {
     test_that("icc", {
       expect_equal(
         icc(m1),
-        structure(list(ICC_adjusted = 0.910433109183341, ICC_conditional = 0.310947768161385,
-                       ICC_unadjusted = 0.310947768161385), class = "icc"),
+        structure(list(
+          ICC_adjusted = 0.910433109183341, ICC_conditional = 0.310947768161385,
+          ICC_unadjusted = 0.310947768161385
+        ), class = "icc"),
         tolerance = 1e-3
       )
     })
@@ -34,8 +36,10 @@ if (.runThisTest && !osx) {
     test_that("icc", {
       expect_equal(
         icc(m2),
-        structure(list(ICC_adjusted = 0.399303562702568, ICC_conditional = 0.216907586891627,
-                       ICC_unadjusted = 0.216907586891627), class = "icc"),
+        structure(list(
+          ICC_adjusted = 0.399303562702568, ICC_conditional = 0.216907586891627,
+          ICC_unadjusted = 0.216907586891627
+        ), class = "icc"),
         tolerance = 1e-3
       )
     })
@@ -55,8 +59,10 @@ if (.runThisTest && !osx) {
       set.seed(123)
       expect_equal(
         icc(m3),
-        structure(list(ICC_adjusted = 0.930217931275196, ICC_conditional = 0.771475122370036,
-                       ICC_unadjusted = 0.771475122370036), class = "icc"),
+        structure(list(
+          ICC_adjusted = 0.930217931275196, ICC_conditional = 0.771475122370036,
+          ICC_unadjusted = 0.771475122370036
+        ), class = "icc"),
         tolerance = 0.05
       )
     })
